% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/flexconn_predict.R
\name{flexconn_predict_patch}
\alias{flexconn_predict_patch}
\alias{flexconn_predict}
\alias{flexconn_predict_with_patches}
\alias{flexconn_predict_with_volume}
\title{Predict from FLEXCONN model}
\usage{
flexconn_predict_patch(model, t1, flair, t2 = NULL, mask = NULL,
  patchsize, verbose = TRUE, ..., batch_size = 1)

flexconn_predict(model, t1, flair, t2 = NULL, mask = NULL,
  type = c("volume", "patch"), patchsize, verbose = TRUE,
  normalize = TRUE, ..., batch_size = 1)

flexconn_predict_with_patches(model, t1, flair, t2 = NULL, mask = NULL,
  patchsize, verbose = TRUE, ..., batch_size = 1)

flexconn_predict_with_volume(model, t1, flair, t2 = NULL,
  verbose = TRUE, normalize = TRUE, ..., batch_size = 1)
}
\arguments{
\item{model}{A keras model object trained}

\item{t1}{3D array or \code{nifti} image}

\item{flair}{3D array or \code{nifti} image}

\item{t2}{3D array or \code{nifti} image, optional if model has this}

\item{mask}{binary 3D array or \code{nifti} image, but of
the whole area of prediction, not the ground truth}

\item{patchsize}{Vector of length 2 (or more)}

\item{verbose}{print diagnostic messages}

\item{...}{additional arguments to \code{\link{get_patches}}}

\item{batch_size}{Size of batches for prediction.
Integer. Passed to
\code{\link[keras]{predict.keras.engine.training.Model}}.}

\item{type}{type of prediction to use, patch-based or slice/volume
based}

\item{normalize}{Run \code{\link{normalize_image}} on the image
before prediction}
}
\value{
A vector of predictions, based on the indices of the
mask
}
\description{
Predict from FLEXCONN model
}
\note{
If \code{mask = NULL}, a mask will be generated for
\code{t1 > 0}.
}
